==> 1.0.0.tar.gz: lib/src/device_service.dart <==
import 'dart:io';

import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:device_info_plus/device_info_plus.dart';

import 'device_model.dart';

enum PlatformName {
  web('Web'),
  android('Android'),
  ios('iOS'),
  macos('macOS'),
  windows('Windows'),
  linux('Linux');

  final String name;

  const PlatformName(this.name);
}

class DeviceService {
  static PlatformName? getDevicePlatformName() {
    if (kIsWeb) {
      return PlatformName.web;
    } else if (Platform.isAndroid) {
      return PlatformName.android;
    } else if (Platform.isIOS) {
      return PlatformName.ios;
    } else if (Platform.isWindows) {
      return PlatformName.windows;
    } else if (Platform.isMacOS) {
      return PlatformName.macos;
    } else if (Platform.isLinux) {
      return PlatformName.linux;
    } else {
      return null;
    }
  }

  static PlatformName? getPlatformByName(String name) {
    return PlatformName.values
        .where((element) => element.name == name)
        .firstOrNull;
  }

  static Future<AppDevice> getDeviceInfo(
      {required String deviceId, String? userIdentifier}) async {
    PlatformName? platformName = DeviceService.getDevicePlatformName();
    AppDevice device = AppDevice(
      id: deviceId,
      userIdentifier: userIdentifier,
      platformName: platformName,
    );

    try {
      DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();

      if (platformName != null) {
        switch (platformName) {
          case PlatformName.web:
            final webInfo = await deviceInfo.webBrowserInfo;

            device.brand = webInfo.vendor;
            device.name = webInfo.browserName.name;
            device.os = webInfo.userAgent;
            break;

          case PlatformName.android:
            final androidInfo = await deviceInfo.androidInfo;

            device.fingerprint = androidInfo.fingerprint;
            device.brand = androidInfo.brand;
            device.model = androidInfo.model;
            device.name = androidInfo.device;
            device.os = androidInfo.version.baseOS;
            break;

          case PlatformName.ios:
            final iosInfo = await deviceInfo.iosInfo;

            device.fingerprint = iosInfo.identifierForVendor;
            device.brand = 'Apple';
            device.model = iosInfo.model;
            device.name = iosInfo.name;
            device.os = iosInfo.systemName;
            break;

          case PlatformName.windows:
            final windowsInfo = await deviceInfo.windowsInfo;

            device.fingerprint = windowsInfo.productId;
            device.name = windowsInfo.computerName;
            device.os = windowsInfo.productName;
            break;

          case PlatformName.macos:
            final macOsInfo = await deviceInfo.macOsInfo;

            device.fingerprint = macOsInfo.systemGUID;
            device.brand = 'Apple';
            device.model = macOsInfo.model;
            device.name = macOsInfo.computerName;
            device.os = macOsInfo.osRelease;
            break;

          case PlatformName.linux:
            final linuxInfo = await deviceInfo.linuxInfo;

            device.fingerprint = linuxInfo.machineId;
            device.os = linuxInfo.name;
            device.name = linuxInfo.prettyName;
            break;
        }
      } else {
        device.name = Platform.localHostname;
      }

      return device;
    } on Exception {
      return device;
    }
  }
}

==> 1.1.0.tar.gz: lib/src/device_service.dart <==
import 'dart:io';

import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:device_info_plus/device_info_plus.dart';

import 'device_model.dart';

enum PlatformName {
  web('Web'),
  android('Android'),
  ios('iOS'),
  macos('macOS'),
  windows('Windows'),
  linux('Linux');

  final String name;

  const PlatformName(this.name);
}

class DeviceService {
  static PlatformName? getDevicePlatformName() {
    if (kIsWeb) {
      return PlatformName.web;
    } else if (Platform.isAndroid) {
      return PlatformName.android;
    } else if (Platform.isIOS) {
      return PlatformName.ios;
    } else if (Platform.isWindows) {
      return PlatformName.windows;
    } else if (Platform.isMacOS) {
      return PlatformName.macos;
    } else if (Platform.isLinux) {
      return PlatformName.linux;
    } else {
      return null;
    }
  }

  static PlatformName? getPlatformByName(String name) {
    return PlatformName.values
        .where((element) => element.name == name)
        .firstOrNull;
  }

  static Future<AppDevice> getDeviceInfo(
      {String? deviceId, String? userIdentifier}) async {
    PlatformName? platformName = DeviceService.getDevicePlatformName();
    AppDevice device = AppDevice(
      id: deviceId,
      userIdentifier: userIdentifier,
      platformName: platformName,
    );

    try {
      DeviceInfoPlugin deviceInfo = DeviceInfoPlugin();

      if (platformName != null) {
        switch (platformName) {
          case PlatformName.web:
            final webInfo = await deviceInfo.webBrowserInfo;

            device.brand = webInfo.vendor;
            device.name = webInfo.browserName.name;
            device.os = webInfo.userAgent;
            break;

          case PlatformName.android:
            final androidInfo = await deviceInfo.androidInfo;

            device.fingerprint = androidInfo.fingerprint;
            device.brand = androidInfo.brand;
            device.model = androidInfo.model;
            device.name = androidInfo.device;
            device.os = androidInfo.version.baseOS;
            break;

          case PlatformName.ios:
            final iosInfo = await deviceInfo.iosInfo;

            device.fingerprint = iosInfo.identifierForVendor;
            device.brand = 'Apple';
            device.model = iosInfo.model;
            device.name = iosInfo.name;
            device.os = iosInfo.systemName;
            break;

          case PlatformName.windows:
            final windowsInfo = await deviceInfo.windowsInfo;

            device.fingerprint = windowsInfo.productId;
            device.name = windowsInfo.computerName;
            device.os = windowsInfo.productName;
            break;

          case PlatformName.macos:
            final macOsInfo = await deviceInfo.macOsInfo;

            device.fingerprint = macOsInfo.systemGUID;
            device.brand = 'Apple';
            device.model = macOsInfo.model;
            device.name = macOsInfo.computerName;
            device.os = macOsInfo.osRelease;
            break;

          case PlatformName.linux:
            final linuxInfo = await deviceInfo.linuxInfo;

            device.fingerprint = linuxInfo.machineId;
            device.os = linuxInfo.name;
            device.name = linuxInfo.prettyName;
            break;
        }
      } else {
        device.name = Platform.localHostname;
      }

      return device;
    } on Exception {
      return device;
    }
  }

  static bool isWebOrDesktop() {
    if (kIsWeb) {
      return true;
    } else {
      return Platform.isWindows || Platform.isMacOS || Platform.isLinux;
    }
  }

  static bool isMobile() {
    if (kIsWeb) {
      return false;
    } else {
      return Platform.isAndroid || Platform.isIOS;
    }
  }
}
